@@ -111,6 +111,7 @@ impl Ecc {
     }
 
     pub fn sign(&mut self, key_slot: u8, data: &[u8]) -> Result<Bytes> {
+        let _ = self.send_command_retries(&EccCommand::random(), false, 1)?;
         let digest = Sha256::digest(data);
         let _ = self.send_command_retries(
             &EccCommand::nonce(DataBuffer::MessageDigest, Bytes::copy_from_slice(&digest)),
@@ -184,9 +185,7 @@ impl Ecc {
             }
             match response {
                 EccResponse::Data(bytes) => return Ok(bytes),
-                EccResponse::Error(err) if err.is_recoverable() && retry < retries => {
-                    continue;
-                }
+                EccResponse::Error(err) if err.is_recoverable() && retry < retries => continue,
                 EccResponse::Error(err) => return Err(Error::ecc(err)),
             }
         }
